library transition_customer;

import 'package:flutter/material.dart';

/// Tipos de Animacióm
enum AnimationType { normal, fadeIn }

class TransitionCustomer {
  final BuildContext context;
  final Widget child;
  final AnimationType animation;
  final Duration duration;
  final bool replacement;

  /// Clase principa, [context] el BuildContext es el de la aplicación
  /// [child] es el widget de destino
  /// [animation] es el tipo de animación
  /// [duration] es el tiempo en milisegundos que queremos que dure la transición
  TransitionCustomer(
      {required this.context,
      required this.child,
      this.animation = AnimationType.normal,
      this.duration = const Duration(milliseconds: 300),
      this.replacement = false}) {
    switch (this.animation) {
      case AnimationType.normal:
        this._normalTransition();
        break;
      case AnimationType.fadeIn:
        this._fadeInTransition();
        break;
    }

//        Navigator.push(this.context, MaterialPageRoute(builder: (_)=>this.child));
  }

  /// Push normal de la página
  void _pushPage(Route route) => Navigator.push(context, route);

  /// Push con reemplazo de la página
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  /// Código de una transición normal
  void _normalTransition() {
    final route = MaterialPageRoute(builder: (_) => this.child);

    (this.replacement) ? _pushReplacementPage(route) : _pushPage(route);
  }

  /// Código de una transicion reemplazada
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: this.duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });

    (this.replacement) ? _pushReplacementPage(route) : _pushPage(route);
  }
}
